@@ -1,6 +1,7 @@
 import sys
 
 sys.path.append("..")  # Adds the module to path
+sys.path.append(".")  # Adds the module to path
 
 import unittest
 
@@ -110,7 +111,35 @@ class TestScatterers(unittest.TestCase):
 
         imaged_scatterer_1 = optics_1(scatterer)
 
-        imaged_scatterer_1.resolve()
+        imaged_scatterer_1.update().resolve()
+
+    def test_MieStratifiedSphere(self):
+        optics_1 = Brightfield(
+            NA=0.7,
+            wavelength=680e-9,
+            resolution=1e-6,
+            magnification=1,
+            output_region=(0, 0, 64, 128),
+            padding=(10, 10, 10, 10),
+            return_field=True,
+            upscale=4,
+        )
+
+        scatterer = scatterers.MieStratifiedSphere(
+            radius=[0.5e-6, 1.5e-6],
+            refractive_index=[1.45 + 0.1j, 1.52],
+            aperature_angle=0.1,
+        )
+        imaged_scatterer_1 = optics_1(scatterer)
+        imaged_scatterer_1.update().resolve()
+
+        scatterer = scatterers.MieStratifiedSphere(
+            radius=[0.5e-6, 1.5e-6, 3e-6],
+            refractive_index=[1.45 + 0.1j, 1.52, 1.23],
+            aperature_angle=0.1,
+        )
+        imaged_scatterer_1 = optics_1(scatterer)
+        imaged_scatterer_1.update().resolve()
 
 
 if __name__ == "__main__":
